//===============================================================================
//  BD7411G.ino
//
// Copyright (c) 2021 ROHM Co.,Ltd.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
//===============================================================================
#include <HardwareSerial.h>
#include <BD7411G.h>

#define BAUDRATE    (115200)
#define SYSTEM_WAIT (500)

BD7411G bd7411g(ANALOG_2_OUT_PIN);
void    error_func(void);

void setup(void)
{
    float32 version;
    int32_t result;

    Serial.begin(BAUDRATE);
    while (!Serial) {}

    result = bd7411g.init();
    if (result == INIT_NG) {
        error_func();
    }

    (void)Serial.println("Arduino executes BD7411G Sample Program Ver1.0");

    version = bd7411g.get_version();
    (void)Serial.print("Arduino executes BD7411G Driver version");
    (void)Serial.println(version);

    return;
}

void loop(void)
{
    uint8_t hall;

    (void)bd7411g.get_val(&hall);
    if (hall == LOW) {
        (void)Serial.println("BD7411G Magnet field: Detect!");
    } else {
        (void)Serial.println("BD7411G Magnet field: Not Detect");
    }
    delay(SYSTEM_WAIT);

    return;
}

void error_func(void)
{
    (void)Serial.println("Initialize error");
    (void)Serial.println("Please check that argument of the constructor is ANALOG_1_OUT_PIN or ANALOG_2_OUT_PIN");
    (void)Serial.println("Arduino stops in error function");
    while (1) {}

    return;
}
